@@ -1,18 +1,30 @@
-#ifndef __EUPHORIASS_H__
-#define __EUPHORIASS_H__
-//============================================================================
-//
-// Terence Welsh Screensaver - Euphoria
-// http://www.reallyslick.com/
-//
-// KDE port by Karl Robillard
-//
-//============================================================================
+/*
+ *  Terence Welsh Screensaver - Euphoria
+ *  http://www.reallyslick.com/
+ *
+ *  Ported to KDE by Karl Robillard
+ *  Copyright (C) 2002  Terence M. Welsh
+ *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License as
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *   
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *   
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
+#ifndef EUPHORIASS_H
+#define EUPHORIASS_H
 
 #include <qgl.h>
 
-#include <kdialogbase.h>
+#include <kdialog.h>
 
 class wisp;
 class QTimer;
@@ -37,7 +49,7 @@ public:
         DefaultModes
     };
 
-    EuphoriaWidget( QWidget* parent=0, const char* name=0 );
+    EuphoriaWidget( QWidget* parent=0 );
     ~EuphoriaWidget();
 
     void updateParameters();
@@ -134,12 +146,12 @@ private:
 
 class QComboBox;
 
-class KEuphoriaSetup : public KDialogBase
+class KEuphoriaSetup : public KDialog
 {
     Q_OBJECT
 
 public:
-    KEuphoriaSetup( QWidget* parent = 0, const char* name = 0 );
+    KEuphoriaSetup( QWidget* parent = 0 );
     ~KEuphoriaSetup();
 
 private slots:
