@@ -22,26 +22,37 @@
 #include <kglobal.h>
 #include <kconfig.h>
 #include <kmessagebox.h>
+#include <krandom.h>
 
 #include "lorenz.h"
 #include "lorenz.moc"
 
 // libkscreensaver interface
-extern "C"
+class KLorenzSaverInterface : public KScreenSaverInterface
 {
-    KDE_EXPORT const char *kss_applicationName = "klorenz.kss";
-    KDE_EXPORT const char *kss_description = I18N_NOOP( "KLorenz" );
-    KDE_EXPORT const char *kss_version = "2.2.0";
 
-    KDE_EXPORT KScreenSaver *kss_create( WId id )
+
+public:
+    virtual KAboutData* aboutData() {
+        return new KAboutData( "klorenz.kss", 0, ki18n( "KLorenz" ), "2.2.0", ki18n( "KLorenz" ) );
+    }
+
+
+    virtual KScreenSaver* create( WId id )
     {
         return new KLorenzSaver( id );
     }
 
-    KDE_EXPORT QDialog *kss_setup()
+    virtual QDialog* setup()
     {
         return new KLorenzSetup();
     }
+};
+
+int main( int argc, char *argv[] )
+{
+    KLorenzSaverInterface kss;
+    return kScreenSaverMain( argc, argv, kss );
 }
 
 #define MINSPEED 1
@@ -66,14 +77,18 @@ extern "C"
 //-----------------------------------------------------------------------------
 // dialog to setup screen saver parameters
 //
-KLorenzSetup::KLorenzSetup( QWidget *parent, const char *name )
-    : KDialogBase( parent, name, true, i18n( "Setup Lorenz Attractor" ),
-      Ok|Cancel|Default|Help, Ok, true )
+KLorenzSetup::KLorenzSetup( QWidget *parent )
+    : KDialog( parent)
 {
-    readSettings();
+	setCaption(i18n( "Setup Lorenz Attractor" ));
+	setButtons(Ok|Cancel|Default|Help);
+	setDefaultButton(Ok);
+    setModal(true);
+	readSettings();
 
     setButtonText( Help, i18n( "A&bout" ) );
-    QWidget *main = makeMainWidget();
+    QWidget *main = new QWidget(this);
+	setMainWidget(main);
 
     QHBoxLayout *tl = new QHBoxLayout( main, 0, spacingHint() );
     QVBoxLayout *tl1 = new QVBoxLayout;
@@ -82,9 +97,9 @@ KLorenzSetup::KLorenzSetup( QWidget *parent, const char *name )
     QLabel *label = new QLabel( i18n("Speed:"), main );
     tl1->addWidget(label);
 
-    sps = new QSlider(MINSPEED, MAXSPEED, 10, speed, QSlider::Horizontal, main);
+    sps = new QSlider(MINSPEED, MAXSPEED, 10, speed, Qt::Horizontal, main);
     sps->setMinimumSize( 120, 20 );
-    sps->setTickmarks(QSlider::Below);
+    sps->setTickPosition(QSlider::TicksBelow);
     sps->setTickInterval(150);
     connect( sps, SIGNAL( valueChanged( int ) ), SLOT( slotSpeed( int ) ) );
     tl1->addWidget(sps);
@@ -92,9 +107,9 @@ KLorenzSetup::KLorenzSetup( QWidget *parent, const char *name )
     label = new QLabel( i18n("Epoch:"), main );
     tl1->addWidget(label);
 
-    eps = new QSlider(MINEPOCH, MAXEPOCH, 100, epoch, QSlider::Horizontal, main);
+    eps = new QSlider(MINEPOCH, MAXEPOCH, 100, epoch, Qt::Horizontal, main);
     eps->setMinimumSize( 120, 20 );
-    eps->setTickmarks(QSlider::Below);
+    eps->setTickPosition(QSlider::TicksBelow);
     eps->setTickInterval(3000);
     connect( eps, SIGNAL( valueChanged( int ) ), SLOT( slotEpoch( int ) ) );
     tl1->addWidget(eps);
@@ -102,9 +117,9 @@ KLorenzSetup::KLorenzSetup( QWidget *parent, const char *name )
     label = new QLabel( i18n("Color rate:"), main );
     tl1->addWidget(label);
 
-    crs = new QSlider(MINCOLOR, MAXCOLOR, 5, crate, QSlider::Horizontal, main);
+    crs = new QSlider(MINCOLOR, MAXCOLOR, 5, crate, Qt::Horizontal, main);
     crs->setMinimumSize( 120, 20 );
-    crs->setTickmarks(QSlider::Below);
+    crs->setTickPosition(QSlider::TicksBelow);
     crs->setTickInterval(10);
     connect( crs, SIGNAL( valueChanged( int ) ), SLOT( slotCRate( int ) ) );
     tl1->addWidget(crs);
@@ -112,9 +127,9 @@ KLorenzSetup::KLorenzSetup( QWidget *parent, const char *name )
     label = new QLabel( i18n("Rotation Z:"), main );
     tl1->addWidget(label);
 
-    zrs = new QSlider(MINZROT, MAXZROT, 18, zrot, QSlider::Horizontal, main);
+    zrs = new QSlider(MINZROT, MAXZROT, 18, zrot, Qt::Horizontal, main);
     zrs->setMinimumSize( 120, 20 );
-    zrs->setTickmarks(QSlider::Below);
+    zrs->setTickPosition(QSlider::TicksBelow);
     zrs->setTickInterval(36);
     connect( zrs, SIGNAL( valueChanged( int ) ), SLOT( slotZRot( int ) ) );
     tl1->addWidget(zrs);
@@ -122,9 +137,9 @@ KLorenzSetup::KLorenzSetup( QWidget *parent, const char *name )
     label = new QLabel( i18n("Rotation Y:"), main );
     tl1->addWidget(label);
 
-    yrs = new QSlider(MINYROT, MAXYROT, 18, yrot, QSlider::Horizontal, main);
+    yrs = new QSlider(MINYROT, MAXYROT, 18, yrot, Qt::Horizontal, main);
     yrs->setMinimumSize( 120, 20 );
-    yrs->setTickmarks(QSlider::Below);
+    yrs->setTickPosition(QSlider::TicksBelow);
     yrs->setTickInterval(36);
     connect( yrs, SIGNAL( valueChanged( int ) ), SLOT( slotYRot( int ) ) );
     tl1->addWidget(yrs);
@@ -132,19 +147,22 @@ KLorenzSetup::KLorenzSetup( QWidget *parent, const char *name )
     label = new QLabel( i18n("Rotation X:"), main );
     tl1->addWidget(label);
 
-    xrs = new QSlider(MINXROT, MAXXROT, 18, xrot, QSlider::Horizontal, main);
+    xrs = new QSlider(MINXROT, MAXXROT, 18, xrot, Qt::Horizontal, main);
     xrs->setMinimumSize( 120, 20 );
-    xrs->setTickmarks(QSlider::Below);
+    xrs->setTickPosition(QSlider::TicksBelow);
     xrs->setTickInterval(36);
     connect( xrs, SIGNAL( valueChanged( int ) ), SLOT( slotXRot( int ) ) );
     tl1->addWidget(xrs);
 
     preview = new QWidget( main );
     preview->setFixedSize( 220, 165 );
-    preview->setBackgroundColor( black );
+    preview->setBackgroundColor( Qt::black );
     preview->show();    // otherwise saver does not get correct size
     saver = new KLorenzSaver( preview->winId() );
     tl->addWidget(preview);
+    connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
+    connect(this,SIGNAL(helpClicked()),this,SLOT(slotHelp()));
+    connect(this,SIGNAL(defaultClicked()),this,SLOT(slotDefault()));
 }
 
 KLorenzSetup::~KLorenzSetup()
@@ -155,15 +173,14 @@ KLorenzSetup::~KLorenzSetup()
 // read settings from config file
 void KLorenzSetup::readSettings()
 {
-    KConfig *config = KGlobal::config();
-    config->setGroup( "Settings" );
+    KConfigGroup config(KGlobal::config(), "Settings");
 
-    speed = config->readNumEntry( "Speed", DEFSPEED );
-    epoch = config->readNumEntry( "Epoch", DEFEPOCH );
-    crate = config->readNumEntry( "Color Rate", DEFCOLOR );
-    zrot = config->readNumEntry( "ZRot", DEFZROT );
-    yrot = config->readNumEntry( "YRot", DEFZROT );
-    xrot = config->readNumEntry( "XRot", DEFZROT );
+    speed = config.readEntry( "Speed", DEFSPEED );
+    epoch = config.readEntry( "Epoch", DEFEPOCH );
+    crate = config.readEntry( "Color Rate", DEFCOLOR );
+    zrot = config.readEntry( "ZRot", DEFZROT );
+    yrot = config.readEntry( "YRot", DEFZROT );
+    xrot = config.readEntry( "XRot", DEFZROT );
 }
 
 
@@ -223,17 +240,16 @@ void KLorenzSetup::slotHelp()
 // Ok pressed - save settings and exit
 void KLorenzSetup::slotOk()
 {
-    KConfig *config = KGlobal::config();
-    config->setGroup( "Settings" );
+    KConfigGroup config(KGlobal::config(), "Settings");
 
-    config->writeEntry( "Speed", speed );
-    config->writeEntry( "Epoch", epoch );
-    config->writeEntry( "Color Rate", crate );
-    config->writeEntry( "ZRot", zrot );
-    config->writeEntry( "YRot", yrot );
-    config->writeEntry( "XRot", xrot );
+    config.writeEntry( "Speed", speed );
+    config.writeEntry( "Epoch", epoch );
+    config.writeEntry( "Color Rate", crate );
+    config.writeEntry( "ZRot", zrot );
+    config.writeEntry( "YRot", yrot );
+    config.writeEntry( "XRot", xrot );
 
-    config->sync();
+    config.sync();
 
     accept();
 }
@@ -265,17 +281,17 @@ void KLorenzSetup::slotDefault()
 
 /*  // User can cancel, or save defaults?
 
-    KConfig *config = KGlobal::config();
-    config->setGroup( "Settings" );
+    KSharedConfig::Ptr config = KGlobal::config();
+    config.setGroup( "Settings" );
 
-    config->writeEntry( "Speed", speed );
-    config->writeEntry( "Epoch", epoch );
-    config->writeEntry( "Color Rate", crate );
-    config->writeEntry( "ZRot", zrot );
-    config->writeEntry( "YRot", yrot );
-    config->writeEntry( "XRot", xrot );
+    config.writeEntry( "Speed", speed );
+    config.writeEntry( "Epoch", epoch );
+    config.writeEntry( "Color Rate", crate );
+    config.writeEntry( "ZRot", zrot );
+    config.writeEntry( "YRot", yrot );
+    config.writeEntry( "XRot", xrot );
 
-    config->sync();
+    config.sync();
 */
 }
 
@@ -441,12 +457,11 @@ KLorenzSaver::KLorenzSaver( WId id ) : KScreenSaver( id )
     mat = new Matrix3D();
     updateMatrix();
 
-    colorContext = QColor::enterAllocContext();
-    setBackgroundColor( black );
+    setBackgroundColor( Qt::black );
     newEpoch();
 
     timer.start( 10 );
-    connect( &timer, SIGNAL( timeout() ), SLOT( drawOnce() ) );
+    connect( &timer, SIGNAL( timeout() ), SLOT( update() ) );
 }
 
 KLorenzSaver::~KLorenzSaver()
@@ -454,23 +469,20 @@ KLorenzSaver::~KLorenzSaver()
     delete mat;
     mat=0;
     timer.stop();
-    QColor::leaveAllocContext();
-    QColor::destroyAllocContext( colorContext );
 }
 
 // read configuration settings from config file
 void KLorenzSaver::readSettings()
 {
-    KConfig *config = KGlobal::config();
-    config->setGroup( "Settings" );
+    KConfigGroup config(KGlobal::config(), "Settings");
 
-    speed = config->readNumEntry( "Speed", DEFSPEED );
-    epoch = config->readNumEntry( "Epoch", DEFEPOCH );
-    zrot = config->readNumEntry( "ZRot", DEFZROT );
-    yrot = config->readNumEntry( "YRot", DEFZROT );
-    xrot = config->readNumEntry( "XRot", DEFZROT );
+    speed = config.readEntry( "Speed", DEFSPEED );
+    epoch = config.readEntry( "Epoch", DEFEPOCH );
+    zrot = config.readEntry( "ZRot", DEFZROT );
+    yrot = config.readEntry( "YRot", DEFZROT );
+    xrot = config.readEntry( "XRot", DEFZROT );
 
-    int crate_num = config->readNumEntry( "Color Rate", DEFCOLOR );
+    int crate_num = config.readEntry( "Color Rate", DEFCOLOR );
     crate = (double)crate_num / (double)MAXCOLOR;
 }
 
@@ -520,12 +532,11 @@ void KLorenzSaver::updateMatrix()
 void KLorenzSaver::newEpoch()
 {
     // Start at a random position, somewhere around the mean
-    x = 0.95-25.0+50.0*kapp->random() / (RAND_MAX+1.0);
-    y = 0.97-25.0+50.0*kapp->random() / (RAND_MAX+1.0);
-    z = 23.6-25.0+50.0*kapp->random() / (RAND_MAX+1.0);
+    x = 0.95-25.0+50.0*KRandom::random() / (RAND_MAX+1.0);
+    y = 0.97-25.0+50.0*KRandom::random() / (RAND_MAX+1.0);
+    z = 23.6-25.0+50.0*KRandom::random() / (RAND_MAX+1.0);
     // start at some random 'time' as well to have different colors
-    t = 10000.0*kapp->random() / (RAND_MAX+1.0);
-    erase();
+    t = 10000.0*KRandom::random() / (RAND_MAX+1.0);
     e=0; // reset epoch counter
 }
 
@@ -539,13 +550,18 @@ static void lorenz(double x, double y, double z, double& dx, double& dy, double&
 
 // Use a simple Runge-Kutta formula to draw a few points
 // No need to go beyond 2nd order for a screensaver!
-void KLorenzSaver::drawOnce()
+void KLorenzSaver::paintEvent(QPaintEvent *)
 {
+    setAttribute( Qt::WA_NoSystemBackground ); // Only after initial clear
+
     double kx, ky, kz, dx, dy, dz;
     const double h = 0.0001;
     const double tqh = h * 3.0 / 4.0;
     QPainter p(this);
 
+    if ( !e )
+        erase();
+
     for (int i=0; i<speed; i++) {
         // Runge-Kutta formula
         lorenz(x,y,z,dx,dy,dz);
@@ -565,5 +581,6 @@ void KLorenzSaver::drawOnce()
                      (int)(ky*height()*1.5/kz)+(int)(height()/2));
         t+=h;
     }
-    if (++e>=epoch) newEpoch();
+    if (++e>=epoch)
+        newEpoch();
 }
