@@ -19,44 +19,32 @@
 #ifndef KPARTSAVER_H_INCLUDED
 #define KPARTSAVER_H_INCLUDED
 
-
-#include <qwidget.h>
-#include <qtimer.h>
-#include <qstring.h>
-#include <qvaluelist.h>
-#include <qdialog.h>
-#include <qpushbutton.h>
-#include <qradiobutton.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qlabel.h>
-
-#include <klocale.h>
-#include <kapplication.h>
-#include <kdebug.h>
-#include <kconfig.h>
-#include <kfiledialog.h>
-#include <kurl.h>
-#include <kparts/part.h>
-#include <ktrader.h>
-#include <kio/jobclasses.h>
-#include <kio/job.h>
-#include <kmimetype.h>
-
 #include <kscreensaver.h>
 
-#include "configwidget.h"
+#include "ui_configwidget.h"
+#include <Q3ValueList>
+class QTimer;
+class QLabel;
+namespace KParts { class ReadOnlyPart; }
+
+class ConfigWidget : public QDialog, public Ui::ConfigWidget
+{
+public:
+  ConfigWidget( QWidget *parent ) : QDialog( parent ) {
+    setupUi( this );
+  }
+};
 
 
 class SaverConfig : public ConfigWidget {
 Q_OBJECT
 
  public:
-    SaverConfig( QWidget* parent = 0, const char* name = 0 );
-    ~SaverConfig(); 
+    SaverConfig( QWidget* parent = 0);
+    ~SaverConfig();
 
  protected slots:
-    void apply();    
+    void apply();
     void add();
     void remove();
     void select();
@@ -74,23 +62,23 @@ Q_OBJECT
 
  public slots:
     void next( bool random );
-    void queue( KURL url );
+    void queue( const KUrl &url );
     void timeout();
-    void closeURL();
+    void closeUrl();
 
- protected:    
+ protected:
     struct Medium {
-	KURL url;
+	KUrl url;
 	bool failed;
-    };   
+    };
 
-    bool openURL(  KURL url );    
+    bool openUrl(  const KUrl& url );
 
-    QValueList<Medium> m_media;
+    Q3ValueList<Medium> m_media;
     QTimer *m_timer;
     KParts::ReadOnlyPart *m_part;
-    int m_current; 
-    
+    int m_current;
+
     bool m_single;
     bool m_random;
     int m_delay;
