@@ -16,11 +16,14 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
-  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 #include "IconifyButton.h"
+//Added by qt3to4:
+#include <QPixmap>
+#include <QMouseEvent>
 
 namespace RiscOS
 {
